==> web-6.0.0.tgz: package/lib/calendar/CalendarView.js <==
import * as React from "react";
import CalendarDayView from "./CalendarDayView";
import CalendarYearView from "./CalendarYearView";
import CalendarMonthView from "./CalendarMonthView";
import CalendarSearsonView from "./CalendarSearsonView";
import { VelocityComponent } from "velocity-react";
import * as Immutable from "immutable";
import { createImmutableMap } from "../createImmutaleMap";
import { SvgIcon } from "../my-icon/index";
var calendarType;
(function (calendarType) {
    calendarType[calendarType["year"] = 1] = "year";
    calendarType[calendarType["searson"] = 2] = "searson";
    calendarType[calendarType["month"] = 3] = "month";
    calendarType[calendarType["day"] = 4] = "day";
})(calendarType || (calendarType = {}));
export default class CalendarView extends React.PureComponent {
    constructor(props) {
        super(props);
        this.changeSelTimeItme = (viewIndex) => {
            const { year, month, day, searson } = this.state.showTimeObj.toJS();
            const { changeBasicState, rotate } = this.props;
            changeBasicState("selTimeArr", function (states) {
                let selTimeArr = states.selTimeArr;
                if (!selTimeArr.size) {
                    selTimeArr = Immutable.fromJS([{ year: "" }]);
                }
                switch (rotate) {
                    case calendarType.day:
                        selTimeArr = selTimeArr.update(viewIndex, map => {
                            return map.withMutations(node => node
                                .set("year", year)
                                .set("month", month)
                                .set("day", day)
                                .set("searson", Math.ceil(month / 3)));
                        });
                        break;
                    case calendarType.searson: {
                        selTimeArr = selTimeArr.update(viewIndex, map => {
                            return map.withMutations(node => node
                                .set("year", year)
                                .set("month", searson * 3 - 2)
                                .set("day", day)
                                .set("searson", searson));
                        });
                        break;
                    }
                    case calendarType.year: {
                        selTimeArr = selTimeArr.update(viewIndex, map => {
                            return map.withMutations(node => node.set("year", year));
                        });
                        break;
                    }
                    case calendarType.month: {
                        selTimeArr = selTimeArr.update(viewIndex, map => {
                            return map.withMutations(node => node
                                .set("year", year)
                                .set("month", month)
                                .set("searson", Math.ceil(month / 3)));
                        });
                        break;
                    }
                    default:
                        selTimeArr = selTimeArr;
                        break;
                }
                return selTimeArr;
            });
        };
        this.clickSelHandle = (e) => {
            const dataset = e.currentTarget.dataset;
            const type = dataset.sign;
            const num = ~~dataset.num;
            const { viewIndex, changeBasicState } = this.props;
            const flag = { [type]: num };
            const _showTimeobj = Object.assign({}, this.state.showTimeObj.toJS(), flag);
            const startGtEnd = changeBasicState("selTimeArr", (state) => state.selTimeArr, {
                viewIndex,
                showTimeObj: _showTimeobj
            });
            if (startGtEnd) {
                alert('开始时间要小于结束时间！');
                return;
            }
            this.setState(pre => {
                return {
                    showTimeObj: pre.showTimeObj.set(type, num),
                };
            }, () => {
                const { rotate, showViewArr, changeBasicState } = this.props;
                this.changeSelTimeItme(viewIndex);
                const panelRotate = showViewArr.findIndex(val => val === "fadeIn");
                if (rotate !== panelRotate) {
                    changeBasicState("showViewArr", function () {
                        let animationArr = new Array(5).fill("fadeOut");
                        animationArr[rotate] = "fadeIn";
                        return animationArr;
                    });
                }
            });
        };
        this.changeView = (e) => {
            const type = e.currentTarget.dataset.sign;
            const { rotate } = this.props;
            this.props.changeBasicState("showViewArr", function (states) {
                const preIndex = states.showViewArr.findIndex(val => val === "fadeIn");
                let showViewArr = [...states.showViewArr];
                showViewArr[preIndex] = "fadeOut";
                if (preIndex === rotate) {
                    showViewArr[calendarType[type]] = "fadeIn";
                }
                else {
                    showViewArr[rotate] = "fadeIn";
                }
                return showViewArr;
            });
        };
        this.changeRotate = (e) => {
            const dom = e.currentTarget;
            if (dom.classList.contains("active")) {
                return;
            }
            const id = (+e.currentTarget.dataset.id);
            this.props.changeBasicState("rotate", function () {
                return id;
            });
        };
        this.controlBtnHandle = (e) => {
            const dataset = e.currentTarget.dataset;
            const type = dataset.sign;
            const curViewIndex = +dataset.curviewindex;
            curViewIndex === calendarType.day
                ? this.updatePanelDays(type)
                : this.updatePanelYears(type);
        };
        this.changeTime = (e) => {
            const name = e.currentTarget.name;
            const viewIndex = +e.currentTarget.dataset.viewindex;
            const { changeBasicState } = this.props;
            let value = ~~e.currentTarget.value;
            value = name === "hour" ? (value > 23 ? 23 : value) : (value > 59 ? 59 : value);
            changeBasicState("selTimeArr", function (states) {
                let selTimeArr = states.selTimeArr;
                if (!selTimeArr.size) {
                    selTimeArr = Immutable.fromJS([{ year: "" }]);
                }
                selTimeArr = selTimeArr.update(viewIndex, map => {
                    return map.withMutations(node => {
                        return node.set(name, value);
                    });
                });
                return selTimeArr;
            });
        };
        const { selTimeObj, curTime } = this.props;
        const showTimeObj = this.getShowTimeObj(selTimeObj, curTime);
        this.state = {
            showTimeObj,
            lastYear: this.getLastYear(showTimeObj.get("year")),
        };
    }
    getShowTimeObj(selTimeObj, curTime) {
        return selTimeObj.getIn([0, "year"])
            ? selTimeObj
            : createImmutableMap(curTime);
    }
    getLastYear(year) {
        let viewIndex = year % 10;
        viewIndex = viewIndex === 0 ? 10 : viewIndex;
        const startTime = year - viewIndex + 1;
        return startTime + 9;
    }
    updatePanelYears(movePre) {
        this.setState(pre => {
            let lastYear = pre.lastYear;
            lastYear =
                movePre === "back" ? lastYear - 10 : lastYear + 1;
            let index = lastYear % 10;
            index = index === 0 ? 10 : index;
            lastYear = lastYear - index + 10;
            return {
                lastYear,
            };
        });
    }
    updatePanelDays(movePre) {
        const { showTimeObj } = this.state;
        const year = showTimeObj.get("year"), month = showTimeObj.get("month");
        let updataMon = 1, updataYear = 1;
        switch (movePre) {
            case "back":
                updataMon = month - 1 === 0 ? 12 : month - 1;
                updataYear = month - 1 === 0 ? year - 1 : year;
                break;
            case "next":
                updataMon = month + 1 === 13 ? 1 : month + 1;
                updataYear = month + 1 === 13 ? year + 1 : year;
                break;
        }
        this.setState({
            showTimeObj: showTimeObj.withMutations((map) => map
                .set("year", updataYear)
                .set("month", updataMon)
                .set("searson", Math.ceil(month / 3))),
        });
    }
    getRotateCombo(arr) {
        const { rotate } = this.props;
        return arr.map((val, index) => {
            const active = index === rotate - 1;
            const id = index + 1;
            return (React.createElement("li", { className: (active && "active") || "", "data-id": id, onClick: this.changeRotate, key: index }, val));
        });
    }
    getSelTime() {
        const { showTimeObj } = this.state;
        const { rotate } = this.props;
        if (rotate === calendarType.day) {
            const year = showTimeObj.get("year");
            const month = `${showTimeObj.get("month")}`.padStart(2, "0");
            return (React.createElement("div", null,
                React.createElement("i", { className: "fa fa-calendar" }),
                "\u00A0",
                React.createElement("span", { "data-sign": "year", onClick: this.changeView },
                    year,
                    "/"),
                React.createElement("span", { "data-sign": "month", onClick: this.changeView }, month)));
        }
        else if (rotate !== calendarType.year) {
            return (React.createElement("div", null,
                React.createElement("i", { className: "fa fa-calendar" }),
                "\u00A0",
                React.createElement("span", { "data-sign": "year", onClick: this.changeView },
                    showTimeObj.get("year"),
                    "\u5E74")));
        }
        else {
            return undefined;
        }
    }
    render() {
        const { curTime, selTimeObj, viewIndex, fixProps: { noChangeRotate, time }, rotate, showViewArr } = this.props;
        const { showTimeObj, lastYear } = this.state;
        console.log(showViewArr, "chld");
        const curViewInde = showViewArr.findIndex(val => val === "fadeIn");
        const showMoveBtn = curViewInde === calendarType.day ||
            curViewInde === calendarType.year;
        let duration = new Array(5).fill(0);
        duration[curViewInde] = 300;
        const arr = ["年", "季", "月", "日"];
        const secondViewName = viewIndex === 1 ? "calendar-view2" : "";
        return (React.createElement("div", { className: `${secondViewName} g-calendar-view` },
            React.createElement("div", { className: "m-viewOpt" },
                React.createElement("div", { style: { position: "relative", }, className: noChangeRotate ? "" : "can-hover" },
                    React.createElement("span", { className: "curViewType " }, arr[curViewInde - 1]),
                    React.createElement("ul", { className: "m-rotate-drop" }, this.getRotateCombo(arr))),
                React.createElement("div", { className: "m-timeSel" }, this.getSelTime()),
                React.createElement("div", { className: "m-moveBtns " + (showMoveBtn ? "" : "hideMoveBtn") },
                    React.createElement("button", { className: "s-btn", onClick: this.controlBtnHandle, "data-sign": "back", "data-curviewindex": curViewInde },
                        React.createElement(SvgIcon, { className: "arrow-pre" }),
                        React.createElement("i", { className: "fa fa-backward" })),
                    React.createElement("button", { className: "s-btn", onClick: this.controlBtnHandle, "data-sign": "next", "data-curviewindex": curViewInde },
                        React.createElement(SvgIcon, { className: "arrow-next" })))),
            React.createElement("div", { className: "m-calendar-view" },
                React.createElement(VelocityComponent, { animation: showViewArr[calendarType.day], duration: duration[calendarType.day] },
                    React.createElement(CalendarDayView, { curTime: curTime, selTimeObj: selTimeObj, showTimeObj: showTimeObj, clickSelHandle: this.clickSelHandle, time: time, changeTime: this.changeTime, viewIndex: viewIndex })),
                React.createElement(VelocityComponent, { animation: showViewArr[calendarType.year], duration: duration[calendarType.year] },
                    React.createElement(CalendarYearView, { curTime: curTime, selTimeObj: selTimeObj, showTimeObj: showTimeObj, clickSelHandle: this.clickSelHandle, rotate: rotate, lastYear: lastYear })),
                React.createElement(VelocityComponent, { animation: showViewArr[calendarType.month], duration: duration[calendarType.month] },
                    React.createElement(CalendarMonthView, { curTime: curTime, selTimeObj: selTimeObj, showTimeObj: showTimeObj, clickSelHandle: this.clickSelHandle, rotate: rotate })),
                React.createElement(VelocityComponent, { animation: showViewArr[calendarType.searson], duration: duration[calendarType.searson] },
                    React.createElement(CalendarSearsonView, { curTime: curTime, selTimeObj: selTimeObj, showTimeObj: showTimeObj, clickSelHandle: this.clickSelHandle })))));
    }
}

==> web-7.0.0.tgz: package/lib/calendar/CalendarView.js <==
import * as React from "react";
import CalendarDayView from "./CalendarDayView";
import CalendarYearView from "./CalendarYearView";
import CalendarMonthView from "./CalendarMonthView";
import CalendarSearsonView from "./CalendarSearsonView";
import { VelocityComponent } from "velocity-react";
import * as Immutable from "immutable";
import { createImmutableMap } from "../util/createImmutaleMap";
import { SvgIcon } from "../my-icon/index";
var calendarType;
(function (calendarType) {
    calendarType[calendarType["year"] = 1] = "year";
    calendarType[calendarType["searson"] = 2] = "searson";
    calendarType[calendarType["month"] = 3] = "month";
    calendarType[calendarType["day"] = 4] = "day";
})(calendarType || (calendarType = {}));
export default class CalendarView extends React.PureComponent {
    constructor(props) {
        super(props);
        this.changeSelTimeItme = (viewIndex) => {
            const { year, month, day, searson } = this.state.showTimeObj.toJS();
            const { changeBasicState, rotate } = this.props;
            changeBasicState("selTimeArr", function (states) {
                let selTimeArr = states.selTimeArr;
                if (!selTimeArr.size) {
                    selTimeArr = Immutable.fromJS([{ year: "" }]);
                }
                switch (rotate) {
                    case calendarType.day:
                        selTimeArr = selTimeArr.update(viewIndex, map => {
                            return map.withMutations(node => node
                                .set("year", year)
                                .set("month", month)
                                .set("day", day)
                                .set("searson", Math.ceil(month / 3)));
                        });
                        break;
                    case calendarType.searson: {
                        selTimeArr = selTimeArr.update(viewIndex, map => {
                            return map.withMutations(node => node
                                .set("year", year)
                                .set("month", searson * 3 - 2)
                                .set("day", day)
                                .set("searson", searson));
                        });
                        break;
                    }
                    case calendarType.year: {
                        selTimeArr = selTimeArr.update(viewIndex, map => {
                            return map.withMutations(node => node.set("year", year));
                        });
                        break;
                    }
                    case calendarType.month: {
                        selTimeArr = selTimeArr.update(viewIndex, map => {
                            return map.withMutations(node => node
                                .set("year", year)
                                .set("month", month)
                                .set("searson", Math.ceil(month / 3)));
                        });
                        break;
                    }
                    default:
                        selTimeArr = selTimeArr;
                        break;
                }
                return selTimeArr;
            });
        };
        this.clickSelHandle = (e) => {
            const dataset = e.currentTarget.dataset;
            const type = dataset.sign;
            const num = ~~dataset.num;
            const { viewIndex, changeBasicState } = this.props;
            const flag = { [type]: num };
            const _showTimeobj = Object.assign({}, this.state.showTimeObj.toJS(), flag);
            const startGtEnd = changeBasicState("selTimeArr", (state) => state.selTimeArr, {
                viewIndex,
                showTimeObj: _showTimeobj
            });
            if (startGtEnd) {
                alert('开始时间要小于结束时间！');
                return;
            }
            this.setState(pre => {
                return {
                    showTimeObj: pre.showTimeObj.set(type, num),
                };
            }, () => {
                const { rotate, showViewArr, changeBasicState } = this.props;
                this.changeSelTimeItme(viewIndex);
                const panelRotate = showViewArr.findIndex(val => val === "fadeIn");
                if (rotate !== panelRotate) {
                    changeBasicState("showViewArr", function () {
                        let animationArr = new Array(5).fill("fadeOut");
                        animationArr[rotate] = "fadeIn";
                        return animationArr;
                    });
                }
            });
        };
        this.changeView = (e) => {
            const type = e.currentTarget.dataset.sign;
            const { rotate } = this.props;
            this.props.changeBasicState("showViewArr", function (states) {
                const preIndex = states.showViewArr.findIndex(val => val === "fadeIn");
                let showViewArr = [...states.showViewArr];
                showViewArr[preIndex] = "fadeOut";
                if (preIndex === rotate) {
                    showViewArr[calendarType[type]] = "fadeIn";
                }
                else {
                    showViewArr[rotate] = "fadeIn";
                }
                return showViewArr;
            });
        };
        this.changeRotate = (e) => {
            const dom = e.currentTarget;
            if (dom.classList.contains("active")) {
                return;
            }
            const id = (+e.currentTarget.dataset.id);
            this.props.changeBasicState("rotate", function () {
                return id;
            });
        };
        this.controlBtnHandle = (e) => {
            const dataset = e.currentTarget.dataset;
            const type = dataset.sign;
            const curViewIndex = +dataset.curviewindex;
            curViewIndex === calendarType.day
                ? this.updatePanelDays(type)
                : this.updatePanelYears(type);
        };
        this.changeTime = (e) => {
            const name = e.currentTarget.name;
            const viewIndex = +e.currentTarget.dataset.viewindex;
            const { changeBasicState } = this.props;
            let value = ~~e.currentTarget.value;
            value = name === "hour" ? (value > 23 ? 23 : value) : (value > 59 ? 59 : value);
            changeBasicState("selTimeArr", function (states) {
                let selTimeArr = states.selTimeArr;
                if (!selTimeArr.size) {
                    selTimeArr = Immutable.fromJS([{ year: "" }]);
                }
                selTimeArr = selTimeArr.update(viewIndex, map => {
                    return map.withMutations(node => {
                        return node.set(name, value);
                    });
                });
                return selTimeArr;
            });
        };
        const { selTimeObj, curTime } = this.props;
        const showTimeObj = this.getShowTimeObj(selTimeObj, curTime);
        this.state = {
            showTimeObj,
            lastYear: this.getLastYear(showTimeObj.get("year")),
        };
    }
    getShowTimeObj(selTimeObj, curTime) {
        return selTimeObj.getIn([0, "year"])
            ? selTimeObj
            : createImmutableMap(curTime);
    }
    getLastYear(year) {
        let viewIndex = year % 10;
        viewIndex = viewIndex === 0 ? 10 : viewIndex;
        const startTime = year - viewIndex + 1;
        return startTime + 9;
    }
    updatePanelYears(movePre) {
        this.setState(pre => {
            let lastYear = pre.lastYear;
            lastYear =
                movePre === "back" ? lastYear - 10 : lastYear + 1;
            let index = lastYear % 10;
            index = index === 0 ? 10 : index;
            lastYear = lastYear - index + 10;
            return {
                lastYear,
            };
        });
    }
    updatePanelDays(movePre) {
        const { showTimeObj } = this.state;
        const year = showTimeObj.get("year"), month = showTimeObj.get("month");
        let updataMon = 1, updataYear = 1;
        switch (movePre) {
            case "back":
                updataMon = month - 1 === 0 ? 12 : month - 1;
                updataYear = month - 1 === 0 ? year - 1 : year;
                break;
            case "next":
                updataMon = month + 1 === 13 ? 1 : month + 1;
                updataYear = month + 1 === 13 ? year + 1 : year;
                break;
        }
        this.setState({
            showTimeObj: showTimeObj.withMutations((map) => map
                .set("year", updataYear)
                .set("month", updataMon)
                .set("searson", Math.ceil(month / 3))),
        });
    }
    getRotateCombo(arr) {
        const { rotate } = this.props;
        return arr.map((val, index) => {
            const active = index === rotate - 1;
            const id = index + 1;
            return (React.createElement("li", { className: (active && "active") || "", "data-id": id, onClick: this.changeRotate, key: index }, val));
        });
    }
    getSelTime() {
        const { showTimeObj } = this.state;
        const { rotate } = this.props;
        if (rotate === calendarType.day) {
            const year = showTimeObj.get("year");
            const month = `${showTimeObj.get("month")}`.padStart(2, "0");
            return (React.createElement("div", null,
                React.createElement("i", { className: "fa fa-calendar" }),
                "\u00A0",
                React.createElement("span", { "data-sign": "year", onClick: this.changeView },
                    year,
                    "/"),
                React.createElement("span", { "data-sign": "month", onClick: this.changeView }, month)));
        }
        else if (rotate !== calendarType.year) {
            return (React.createElement("div", null,
                React.createElement("i", { className: "fa fa-calendar" }),
                "\u00A0",
                React.createElement("span", { "data-sign": "year", onClick: this.changeView },
                    showTimeObj.get("year"),
                    "\u5E74")));
        }
        else {
            return undefined;
        }
    }
    render() {
        const { curTime, selTimeObj, viewIndex, fixProps: { noChangeRotate, time }, rotate, showViewArr } = this.props;
        const { showTimeObj, lastYear } = this.state;
        console.log(showViewArr, "chld");
        const curViewInde = showViewArr.findIndex(val => val === "fadeIn");
        const showMoveBtn = curViewInde === calendarType.day ||
            curViewInde === calendarType.year;
        let duration = new Array(5).fill(0);
        duration[curViewInde] = 300;
        const arr = ["年", "季", "月", "日"];
        const secondViewName = viewIndex === 1 ? "calendar-view2" : "";
        return (React.createElement("div", { className: `${secondViewName} g-calendar-view` },
            React.createElement("div", { className: "m-viewOpt" },
                React.createElement("div", { style: { position: "relative", }, className: noChangeRotate ? "" : "can-hover" },
                    React.createElement("span", { className: "curViewType " }, arr[curViewInde - 1]),
                    React.createElement("ul", { className: "m-rotate-drop" }, this.getRotateCombo(arr))),
                React.createElement("div", { className: "m-timeSel" }, this.getSelTime()),
                React.createElement("div", { className: "m-moveBtns " + (showMoveBtn ? "" : "hideMoveBtn") },
                    React.createElement("button", { className: "s-btn", onClick: this.controlBtnHandle, "data-sign": "back", "data-curviewindex": curViewInde },
                        React.createElement(SvgIcon, { className: "arrow-pre" }),
                        React.createElement("i", { className: "fa fa-backward" })),
                    React.createElement("button", { className: "s-btn", onClick: this.controlBtnHandle, "data-sign": "next", "data-curviewindex": curViewInde },
                        React.createElement(SvgIcon, { className: "arrow-next" })))),
            React.createElement("div", { className: "m-calendar-view" },
                React.createElement(VelocityComponent, { animation: showViewArr[calendarType.day], duration: duration[calendarType.day] },
                    React.createElement(CalendarDayView, { curTime: curTime, selTimeObj: selTimeObj, showTimeObj: showTimeObj, clickSelHandle: this.clickSelHandle, time: time, changeTime: this.changeTime, viewIndex: viewIndex })),
                React.createElement(VelocityComponent, { animation: showViewArr[calendarType.year], duration: duration[calendarType.year] },
                    React.createElement(CalendarYearView, { curTime: curTime, selTimeObj: selTimeObj, showTimeObj: showTimeObj, clickSelHandle: this.clickSelHandle, rotate: rotate, lastYear: lastYear })),
                React.createElement(VelocityComponent, { animation: showViewArr[calendarType.month], duration: duration[calendarType.month] },
                    React.createElement(CalendarMonthView, { curTime: curTime, selTimeObj: selTimeObj, showTimeObj: showTimeObj, clickSelHandle: this.clickSelHandle, rotate: rotate })),
                React.createElement(VelocityComponent, { animation: showViewArr[calendarType.searson], duration: duration[calendarType.searson] },
                    React.createElement(CalendarSearsonView, { curTime: curTime, selTimeObj: selTimeObj, showTimeObj: showTimeObj, clickSelHandle: this.clickSelHandle })))));
    }
}
